@@ -35,9 +35,12 @@ class DBClient:
         self.conn = DBClient._connection
 
     def close(self):
+        import pg8000 # lazy
         if self.conn is not None:
             try:
                 self.conn.close()
+            except pg8000.exceptions.InterfaceError:
+                pass
             finally:
                 DBClient._connection = None
 
@@ -97,7 +100,8 @@ class PostgresPipe(QueryPipe,Integration):
     examples = [
         ['myquery.sql', 'postgres:mydb', '-'],
         ["{'query': 'SELECT * from MY_TABLE;'}", 'postgres:mydb', '-'],
-        ["{'query': 'SELECT * FROM pg_catalog.pg_tables;'}", 'postgres:mydb']
+        ["{'query': 'SELECT * FROM pg_catalog.pg_tables;'}", 'postgres:mydb'],
+        ["{'query': 'SELECT stored_procedure(%s, ...), batch_params:{...}"]
     ]
 
     # name, type, default
@@ -122,10 +126,15 @@ class PostgresPipe(QueryPipe,Integration):
 
         self.params_field = "params"  # optional: list/tuple (positional) or dict (named)
 
+        self.client = None
+
     def reset(self):
         # stateless across reset
         pass
 
+    def close(self):
+        self.client.close()
+
     def _make_header(self, cur, query: str, params=None) -> Dict[str, Any]:
         """
         Inspect the cursor and build a full header record.
@@ -154,7 +163,7 @@ class PostgresPipe(QueryPipe,Integration):
         return h
 
     def execute_query_returning_S_xO_iterable(self, record):
-        client = DBClient(
+        self.client = DBClient(
             host=self.db_host,
             username=self.db_user,
             password=self.db_pass,
@@ -165,14 +174,32 @@ class PostgresPipe(QueryPipe,Integration):
         try:
             query = record.get(self.query_field)
             if not query:
-                    record['_error'] = 'missing query'
-                    yield record
-            else:        
-                params = record.get(self.params_field)
+                record['_error'] = 'missing query'
+                yield record
+                return
 
-                cur = client.conn.cursor()
-                try:
-                    # execute
+            params = record.get(self.params_field)          # single-exec params
+            batch  = record.get("batch_params", None)       # list[tuple|dict] for batching
+
+            cur = self.client.conn.cursor()
+            try:
+                did_executemany = False
+
+                # ---------- execute ----------
+                if batch is not None:
+                    # Handle batch sizes explicitly to preserve single-SELECT streaming semantics
+                    if len(batch) == 0:
+                        # No-op batch; execute a lightweight statement so we can still emit a header
+                        cur.execute("SELECT 1")
+                        header_params = {"batch_size": 0}
+                    elif len(batch) == 1:
+                        cur.execute(query, batch[0])
+                        header_params = batch[0]
+                    else:
+                        cur.executemany(query, batch)
+                        did_executemany = True
+                        header_params = {"batch_size": len(batch)}
+                else:
                     if params is None:
                         cur.execute(query)
                     else:
@@ -180,17 +207,21 @@ class PostgresPipe(QueryPipe,Integration):
                             cur.execute(query, params)
                         else:
                             cur.execute(query, (params,))
+                    header_params = params
 
-                    # yield header first
-                    yield self._make_header(cur, query, params)
+                # ---------- header ----------
+                yield self._make_header(cur, query, header_params)
 
-                    # then stream rows if it was a real SELECT with results
-                    if cur.description:
-                        cols = [d[0] for d in cur.description]
-                        if not (len(cols) == 1 and cols[0] == "ingest_event"):
-                            for row in cur:
-                                yield _row_to_dict(cur, row)
-                finally:
-                    cur.close()
+                # ---------- stream rows (only meaningful for single execute that returns rows) ----------
+                # Note: executemany() typically doesn't expose per-execution result sets.
+                if not did_executemany and cur.description:
+                    cols = [d[0] for d in cur.description]
+                    if not (len(cols) == 1 and cols[0] == "ingest_event"):
+                        for row in cur:
+                            yield _row_to_dict(cur, row)
+
+            finally:
+                cur.close()
         finally:
-            client.close()
+            pass
+        #    client.close()
